GOOF----LE-8-2.0      ]  4   h      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-1	 		g  filenameS	
f  srfi/srfi-1.scm	g  exportsS	g  xcons	
g  
list-tabulate	g  	list-copy	g  
circular-list	g  proper-list?	g  circular-list?	g  dotted-list?	g  
null-list?	g  	not-pair?	g  list=	g  first	g  second	g  third	g  fourth	g  fifth	g  sixth	g  seventh	g  eighth	g  ninth	g  tenth	 g  car+cdr	!g  take	"g  drop	#g  
take-right	$g  
drop-right	%g  take!	&g  drop-right!	'g  split-at	(g  	split-at!	)g  last	*g  length+	+g  concatenate	,g  concatenate!	-g  append-reverse	.g  append-reverse!	/g  zip	0g  unzip1	1g  unzip2	2g  unzip3	3g  unzip4	4g  unzip5	5g  count	6g  fold	7g  
fold-right	8g  	pair-fold	9g  pair-fold-right	:g  reduce	;g  reduce-right	<g  unfold	=g  unfold-right	>g  
append-map	?g  append-map!	@g  map!	Ag  
pair-for-each	Bg  
filter-map	Cg  	partition	Dg  remove	Eg  
partition!	Fg  remove!	Gg  find	Hg  	find-tail	Ig  
take-while	Jg  take-while!	Kg  
drop-while	Lg  span	Mg  span!	Ng  break	Og  break!	Pg  any	Qg  every	Rg  delete-duplicates	Sg  delete-duplicates!	Tg  
alist-cons	Ug  
alist-copy	Vg  alist-delete	Wg  
alist-delete!	Xg  lset<=	Yg  lset=	Zg  lset-adjoin	[g  
lset-union	\g  lset-intersection	]g  lset-difference	^g  lset-xor	_g  lset-diff+intersection	`g  lset-union!	ag  lset-intersection!	bg  lset-difference!	cg  	lset-xor!	dg  lset-diff+intersection!	e
 !"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_`abcd Y	fg  
re-exportsS	gg  cons	hg  list	ig  cons*	jg  	make-list	kg  pair?	lg  null?	mg  car	ng  cdr	og  caar	pg  cadr	qg  cdar	rg  cddr	sg  caaar	tg  caadr	ug  cadar	vg  caddr	wg  cdaar	xg  cdadr	yg  cddar	zg  cdddr	{g  caaaar	|g  caaadr	}g  caadar	~g  caaddr	g  cadaar g  cadadr g  caddar g  cadddr g  cdaaar g  cdaadr g  cdadar g  cdaddr g  cddaar g  cddadr g  cdddar g  cddddr g  list-ref g  	last-pair g  length g  append g  append! g  reverse g  reverse! g  filter g  filter! g  memq g  memv g  assq g  assv g  set-car! g  set-cdr! ghijklmnopqrstuvwxyz{|}~ 3 g  replacementsS g  iota g  map g  for-each g  map-in-order g  
list-index g  member g  delete g  delete! g  assoc  
 g  set-current-module     g  cond-expand-provide g  current-module   g  load-extension g  
string-append f  	libguile- g  effective-version f  scm_init_srfi_1 g  	scm-error g  wrong-type-arg g  symbol->string f  Wrong type argument: ~S g  make-syntax-transformer     g  	check-arg g  macro g  $sc-dispatch     PPPP  g  
syntax-object g  if g  top   g  ribcage g  dummy g  pred g  arg g  caller   g  m-okn45PQiHG7PFXKGcq79DN-116311     f  l-okn45PQiHG7PFXKGcq79DN-116316 f  l-okn45PQiHG7PFXKGcq79DN-116317 f  l-okn45PQiHG7PFXKGcq79DN-116318 f  l-okn45PQiHG7PFXKGcq79DN-116319       g  x     f  l-okn45PQiHG7PFXKGcq79DN-116313       g  hygiene     g  not     g  quote   g  syntax-violation     f  -source expression failed to match any pattern g  out-of-range f  Value out of range: ~A g  integer? g  non-negative-integer? g  error f  not a proper list in null-list? g  
procedure? g  	list-head g  	list-tail g  any1 f  map f  Circular list: ~S f  Not a list: ~S g  min f  .Args do not contain a proper (finite) list: ~S f  for-each g  apply g  every1 g  acons g  equal? g  eq? g  eqv?C 5     h    ]4	
ef5	 4 >  "  G   4i4i5 >  "  G  4i4i4i5 5>  "  G         h      ] C       g  d
		 g  a		  g  filenamef  srfi/srfi-1.scm
 
	 	 			  g  nameg  xconsg  
documentationf  dLike `cons', but with interchanged arguments.  Useful mostly when passed to
higher-order procedures. CR   h      ]4 5 6        g  caller
		 g  arg		  g  filenamef  srfi/srfi-1.scm
 
	 	
	 		 	
	 	'	 	2	 	 			  g  nameg  wrong-type-arg CR4    h(   d   ]     C      \       g  dummy
		" g  pred		" g  arg			" g  caller			"  		"	   C     h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  srfi/srfi-1.scm
 
 		"  g  
macro-typeg  syntax-rulesg  patternsg  predg  argg  caller   C5R     h      ]   6         g  proc
		 g  arg		  g  filenamef  srfi/srfi-1.scm
 
	 	
	
 	
	 	&	 	1	 	 			  g  nameg  out-of-range CR   h      ]4 5$   
CC           g  x
		  g  filenamef  srfi/srfi-1.scm
 
	 	'	
 	"	 	4 		  g  nameg  non-negative-integer? CR
    hX     ]4 5$  "  4 >  "  G  "  !
$  C45" "         g  n
		U g  	init-proc		U g  n		)	J g  acc		)	J  g  filenamef  srfi/srfi-1.scm
 
			)		-		1		7		8		=	%	?		B		J		J		M		U	 		U	  g  nameg  
list-tabulateg  
documentationf  Return an N-element list, where each list element is produced by applying the
procedure INIT-PROC to the corresponding list index.  The order in which
INIT-PROC is applied to the indices is not specified. C
R     h(      - 1 3 H JK4J5JJC              g  elt1
	
	! g  elts	
	!  g  filenamef  srfi/srfi-1.scm

		
								 			!
  g  nameg  
circular-list CR   hx   "  - . , 3 #  
#  4 5$  "  4 >  "  G  "  % $  6"
"          g  count
		t g  start		t g  step			t g  n		E	j g  acc		E	j  g  filenamef  srfi/srfi-1.scm

	
		E		J		N		T		W		^	#	_		b		j		j		l		t	 		t	  g  nameg  iota CR h   t   ] C  l       g  x
		  g  filenamef  srfi/srfi-1.scm

		 		  g  nameg  proper-list? CR   hX   6  ]4 5$  C"  745$  C45$  C&  C"  " .      g  x
		W g  hare		J g  tortoise			J g  hare		#	J  g  filenamef  srfi/srfi-1.scm

			
					
			#		#		&		0	
	:!		?#		B#		J#		J		M		W	 		W  g  nameg  circular-list? CR hp   F  ] (  C4 5$  C"  G(  C45$  C(  C45$  C&  C"  " >      g  x
		o g  hare		b g  tortoise			b g  hare		3	b  g  filenamef  srfi/srfi-1.scm
%
	&		(		&		*		!+		$-	
	.+		3/		3/	
	;0		>2		H0		W5		Z5		b5		b*		e*		o*	 		o  g  nameg  dotted-list? CR   h(      ]4 5$   C4 5$  C6           g  x
		$  g  filenamef  srfi/srfi-1.scm
7
	9		
8		:		;		8		">		$>	 			$  g  nameg  
null-list? CR   h   I  ] C A      g  x
		  g  filenamef  srfi/srfi-1.scm
@
	E		E	 		  g  nameg  	not-pair?g  
documentationf  Return #t if X is not a pair, #f otherwise.

This is shorthand notation `(not (pair? X))' and is supposed to be used for
end-of-list checking in contexts where dotted lists are allowed. CR hH   
  ]"  1(  C(  C4L 5$  "C "           g  a
		C g  b		C g  a			7 g  b			7  g  filenamef  srfi/srfi-1.scm
H		I		J		K	
	J		O		O		!O	 	#O		'O	
	*P		-P		5P		7I	 		C	  g  nameg  lists-equal C  hx   <  - 1 3 O  Q 4 5$  "  4 >  "  G  (  C"  *$  C45$  	"C" 4      g  elt=
			w g  rest			w g  lists-equal			w g  lists		E	o g  t		I	o  g  filenamef  srfi/srfi-1.scm
G
	R		?S		@S		ET		HU		IU		IU		UV		ZV		]V	*	`V		dV		gW		mW		oT	 			w
  g  nameg  list= CRmiRpiRviRiR   h   v   ] C      n       g  x
		
  g  filenamef  srfi/srfi-1.scm
_
	_			_	 		
  g  nameg  fifth CR     h   v   ] C     n       g  x
		  g  filenamef  srfi/srfi-1.scm
`
	`			`	 		  g  nameg  sixth CR     h   x   ] C    p       g  x
		  g  filenamef  srfi/srfi-1.scm
a
	a			a	 		  g  nameg  seventh CR   h   w   ] C   o       g  x
		
  g  filenamef  srfi/srfi-1.scm
b
	b			b	 		
  g  nameg  eighth CR    h      ] C  w       g  x
		  g  filenamef  srfi/srfi-1.scm
c
	c			c		
c	 		  g  nameg  ninth CR    h      ] C w       g  x
		  g  filenamef  srfi/srfi-1.scm
d
	d	 		d		
d	 		  g  nameg  tenth CR    h      ]  D             g  x
		
  g  filenamef  srfi/srfi-1.scm
f
	h	
	h		
h	 		
  g  nameg  car+cdrg  
documentationf  3Return two values, the `car' and the `cdr' of PAIR. C Ri!Ri"R"       h8      ]"  $  "C 4 5"              g  lis
		1 g  k		1 g  lag			 g  lead			  g  filenamef  srfi/srfi-1.scm
q
	r			s		
s		t		t		t		r		!r		1r	 		1	  g  nameg  
take-right C#R"       h@   &  ]"  #$  "6 4 5"       g  lis
		? g  k		? g  lag			) g  lead			) g  result			)  g  filenamef  srfi/srfi-1.scm
w
	x			y		
y		z		z		z	'	z	!	#z		){		)x		,x		5x	1	?x	 		?	  g  nameg  
drop-right C$R" h      ]

$  C4 5 C       g  lst
		 g  i		 g  tail			  g  filenamef  srfi/srfi-1.scm
}
			
				
											 			  g  nameg  take!g  
documentationf   Linear-update variant of `take'. C%R" hP   }  ]4 5(  C"  %(  $   C C" "     u      g  lst
		K g  i		K g  tail			K g  prev			> g  tail			>  g  filenamef  srfi/srfi-1.scm

												
	"		&		)	#	*		3		6		>		>		C		K	 		K	  g  nameg  drop-right!g  
documentationf  &Linear-update variant of `drop-right'. C&R'      hP     ]
$  6"  )
$  45D" "        g  lst
		N g  i		N g  l			? g  n			? g  acc			?  g  filenamef  srfi/srfi-1.scm

			
														)		,		/		2	&	5	 	?		?		D	"	N	 		N	  g  nameg  split-atg  
documentationf  [Return two values, a list of the elements before index I in LST, and
a list of those after. C'R(    hX     ]
$  6
$   D"  %
$   D" "         g  lst
		U g  i		U g  l		#	H g  n		#	H g  tmp		.	:  g  filenamef  srfi/srfi-1.scm

				
																	#			'		+		.		.		3		4		:		=		@		H		H			M		U		 		U	  g  nameg  	split-at!g  
documentationf  $Linear-update variant of `split-at'. C(R       h      ]4 5C            g  pair
		  g  filenamef  srfi/srfi-1.scm

			
	 		  g  nameg  lastg  
documentationf  ;Return the last element of the non-empty, finite list PAIR. C)RPlnm    hP     - 1 3 "  045$  64545" "            g  clist1
			K g  rest			K g  l		
	= g  acc		
	=  g  filenamef  srfi/srfi-1.scm

	
						 		!	
	*		5		=		=		B		C	'	K	 			K
  g  nameg  zip C/R       h   n   ] 6      f       g  l
		
  g  filenamef  srfi/srfi-1.scm

	
	 		
  g  nameg  unzip1 C0R     h      ]4 54 5D  x       g  l
		  g  filenamef  srfi/srfi-1.scm

		
				 		  g  nameg  unzip2 C1R h       ]4 54 54 5D        g  l
		  g  filenamef  srfi/srfi-1.scm

		
				'		 		  g  nameg  unzip3 C2R      h(      ]4 54 54 54 5D       g  l
		(  g  filenamef  srfi/srfi-1.scm

		
				'		5	(	 		(  g  nameg  unzip4 C3R   h8      ]4 54 54 54 54 5D              g  l
		1  g  filenamef  srfi/srfi-1.scm

		
				'		5	'	
	1	 		1  g  nameg  unzip5 C4R6Plmn 
   h     - 1 3 4 5$  "  4 >  "  G  (  ."  (  C4 5"""  A45$  C45454 4	 5?""          g  kons
		  g  knil		  g  list1			  g  rest			  g  knil		6	T g  list1		6	T g  knil		d  g  lists		d  g  cars	   g  cdrs	    
g  filenamef  srfi/srfi-1.scm

	
		2		6		<		@		E		I		L	'	T		T		d		e		q		u		~	 	 	 	 	+ 	 	 	 	 	! 	 		 	
	  g  nameg  foldg  
documentationf  uApply PROC to the elements of LIST1 ... LISTN to build a result, and return
that result.  See the manual for details. C6R7lnm      h     - 1 3 4 5$  "  4 >  "  G  (  3"  (  C4 5"45""  945$  C454 4	4
5 5?"45"      g  kons
		  g  knil		  g  clist1			  g  rest			  g  lst		6	T g  result		6	T g  lists		i  g  result		i   g  filenamef  srfi/srfi-1.scm

	
		2		6		<		B		C		H		L		T		T		U		e		i		j		v		z	 	 	 	' 	7 	 	 	 	 	 	& 	 	 		 	
	  g  nameg  
fold-right C7R8Pln 	      h     - 1 3 4 5$  "  4 >  "  G  (  1"  !(  C4 5"""  645$  C454 4 5?""          g  kons
		  g  knil		  g  clist1			  g  rest			  g  knil		6	W g  list1		6	W g  tail		B	W g  knil		g  g  lists		g  g  tails	    
g  filenamef  srfi/srfi-1.scm

	
		2		6		<		B		B		E		W		W		g		h		t		x	 	 	 	 	, 	 	 	 	 	! 	 		 	
	  g  nameg  	pair-fold C8R9     h       ] (  LCL  4L 56              g  list1
		  g  filenamef  srfi/srfi-1.scm
											 		  g  nameg  f CPln        h0      ]4 5$  LCL 4 4L4 55 5@         g  lists
		.  g  filenamef  srfi/srfi-1.scm
			
						)		,	'	)	*	#	,		.	 		.  g  nameg  f C       hh      - 1 3 4 5$  "  4 >  "  G  (  O  Q 6O  Q 6        g  kons
			g g  knil			g g  clist1				g g  rest				g g  f		<	K g  f		U	g  g  filenamef  srfi/srfi-1.scm

	
		2		<		U		e		g	 			g	
	  g  nameg  pair-fold-right C9R  h   \   ]C    T       g  x
		  g  filenamef  srfi/srfi-1.scm
	1		= 		   C<   h    - . , 3 	#  "  /"  (  C"45"4 5$  "  4 >  "  G  45$  "  4>  "  G  45$  "  4>  "  G  45$  "  4>  "  G  "  04 5$  "*4545""    
      g  p
	 g  f	 g  g		 g  seed		 g  tail-gen		 g  lst			I g  seed			I g  lst			8 g  result			8 g  seed	 	 g  result	 	  g  filenamef  srfi/srfi-1.scm

					$		*			-
		0
		8		
	8		;		I		J		m
	 	 	 	 	 	 	 	 								 		  g  nameg  unfold C<R= h   O  - . , 3 #  4 5$  "  4 >  "  G  45$  "  4>  "  G  45$  "  4>  "  G  "  '4 5$  C4545""   G      g  p
	  g  f	  g  g		  g  seed		  g  tail		  g  seed	   g  lis	    g  filenamef  srfi/srfi-1.scm

		3			9		\	 	 	 	 	 	 	 	 	 	 	  g  nameg  unfold-right C=R:6  h@     ]4 5$  "  4 >  "  G  (  C 6            g  f
		: g  	ridentity		: g  lst			:  g  filenamef  srfi/srfi-1.scm
 
	%		+&		5(		8(		:(	 		:	  g  nameg  reduceg  
documentationf  `reduce' is a variant of `fold', where the first call to F is on two
elements from LST, rather than one element and a given initial value.
If LST is empty, RIDENTITY is returned.  If LST has just one element
then that's the return value. C:R:        h     ] 456             g  f
		 g  	ridentity		 g  lst			  g  filenamef  srfi/srfi-1.scm
*
		/		/	 			  g  nameg  reduce-rightg  
documentationf  `reduce-right' is a variant of `fold-right', where the first call to
F is on two elements from LST, rather than one element and a given
initial value.  If LST is empty, RIDENTITY is returned.  If LST
has just one element then that's the return value. C;R6*   h(      ]
4 5$  $  6CC          g  ls
		% g  len		% g  ls-len				%  g  filenamef  srfi/srfi-1.scm
F		G	&		G		H		I		I	) 		%	   C*nm     h    )   3 4 5$  "  4 >  "  G  "  |$  Y$  6&   64 5"4 5"(  6	 6"r- 1 3 4 5$  "  4 >  "  G  4
455$  "  4
 >  "  G  "  =
$  6454 45?""             g  f
		  g  l		  g  hare		0  g  tortoise		0  g  move?		0  g  out		0  g  f
 y g  l1 y g  rest	 y g  len	 y g  l1	)f g  rest	)f g  len	)f g  out	)f  g  filenamef  srfi/srfi-1.scm
2		
4		05		36		76		=7		E8		I9		K9	.	M9	4	R:		U9		X;		[;	$	]<		b<	 	d<		g<		s;		v=		z>		>	 >	 >	 =	 ?	 @	 A	 A	* A	0 B	 A	 5	 5	6 5	 2	 E	 F	 K	 F	 F	M	N	N	
N	&O	P	P	N	)Q	,R	
1R		7S	
:T	;T	FT	+GU	LU	"MU	+WU	ZU	fT	
fQ	mQ	5yQ	 B		 	  y	
	  g  nameg  map CRiR6* h(      ]
4 5$  $  6CC          g  ls
		% g  len		% g  ls-len				%  g  filenamef  srfi/srfi-1.scm
p		q	&		q		r		s		s	) 		%	   C*mn   h  Z  )   3 4 5$  "  4 >  "  G  "  $  e$  <&   64 >  "  G  "4 >  "  G  "(  C 6"m- 1 3 4 5$  "  4 >  "  G  4	
455$  "  4 >  "  G  "  A
$  74
 45>  "  G  45"C" R      g  f
		  g  l		  g  hare		0  g  tortoise		0  g  move?		0  g  f
  g  l1  g  rest	  g  len	  g  l1	.o g  rest	.o g  len	.o  g  filenamef  srfi/srfi-1.scm
Z		
\		0]		3^		7^		=_		E`		Ia		Ka	.	Ma	9	Rb		Ua		Vd		[d		`d		ke	 	ne	+	ye		zg		g	 g	 h	 h	 j	 k	 k	* k	5 l	 k	 ]	 Z	 o	 p	 u	 p	 p	w	x	x	x	&y	z	z	"x	.{	2|	
6|		7~	>~	?~	!L~	W	X	#c	2m	o{	 9		 	  	
	  g  nameg  for-each CR+   h      - 1 3 4 ?6       g  f
			 g  clist1			 g  rest				  g  filenamef  srfi/srfi-1.scm

				 				
	  g  nameg  
append-map C>R, h      - 1 3 4 ?6       g  f
			 g  clist1			 g  rest				  g  filenamef  srfi/srfi-1.scm

				 				
	  g  nameg  append-map! C?Ri@RBlmn 
  h     - 1 3 4 5$  "  4 >  "  G  (  H"  9(  64 5$  """"  R45$  64 45?$  4	5"4	5""        g  proc
		  g  list1		  g  rest			  g  l		6	o g  rl		6	o g  res		J	o g  l		~  g  rl		~  g  res	    	g  filenamef  srfi/srfi-1.scm

	
		2		6		<		B		C		H		J		J		R		U		Z		b		e		o		o		r		z		~			 	 	 	 	# 	 	 	 	 	" 	 	 	 	 	 	 	 &		 	
	  g  nameg  
filter-mapg  
documentationf  Apply PROC to the elements of LIST1... and return a list of the
results as per SRFI-1 `map', except that any #f results are omitted from
the list returned. CBRAln 	       h   V  - 1 3 4 5$  "  4 >  "  G  (  /"  #(  C4 >  "  G  """  245$  C4 >  "  G  45""      N      g  f
		  g  clist1		  g  rest			  g  l		6	Y g  l		e   g  filenamef  srfi/srfi-1.scm

	
		2		6		<		?	
	S		Y	
	Y		e		f	
	r		u	
 	 	
 	 	 	 		 	
	  g  nameg  
pair-for-each CARI     h     ]4 5$  "  4 >  "  G  (  C4 5$  H "  /(  C4 5$   "C"C           g  pred
	  g  ls	  g  result		?  g  ls		E	t g  p		E	t  g  filenamef  srfi/srfi-1.scm

			+		,		.		3		5		9		<		?		?			E		K	
	O		T		V		Z	
	_	&	b	 	c		f		i	!	q		t		w	 	 	 	 	  g  nameg  
take-whileg  
documentationf  jReturn a new list which is the longest initial prefix of LS whose
elements all satisfy the predicate PRED. CIRJ    hh   e  ]4 5$  "  4 >  "  G  "  2(  C4 5$  
"$  CC"  ]      g  pred
		f g  lst		f g  prev		)	[ g  rest		)	[  g  filenamef  srfi/srfi-1.scm

			)		/		3		8		:		>		C		K		N		R		U	 	V		Z		[	 		f	  g  nameg  take-while!g  
documentationf  &Linear-update variant of `take-while'. CJRK      hX   \  ]
4 5$  "  4 >  "  G  "   (  C4 5$  	"C"       T      g  pred
		Q g  lst		Q g  lst		)	I  g  filenamef  srfi/srfi-1.scm

			)		/		0		2		7		9		=		@		F		I	 
		Q	  g  nameg  
drop-whileg  
documentationf  UDrop the longest initial prefix of LST whose elements all satisfy the
predicate PRED. CKRL     hh     ]4 5$  "  4 >  "  G  "  3(  "  4 5$  "45D"       g  pred
		g g  lst		g g  lst		)	\ g  rl		)	\  g  filenamef  srfi/srfi-1.scm

			)		/		5	
	:		<	
	@		C		F		I		Q		R		\		\		_		g	 		g	  g  nameg  spang  
documentationf  }Return two values, the longest initial prefix of LST whose elements
all satisfy the predicate PRED, and the remainder of LST. CLRM        hp   ~  ]4 5$  "  4 >  "  G  "  :(  D4 5$  
"$  
DD"  v      g  pred
		n g  list		n g  prev		)	c g  rest		)	c  g  filenamef  srfi/srfi-1.scm

			)		/		2		4		5		:		<		@		E		M		P		T		W	 	X		^		_		c		c	 		n	  g  nameg  span!g  
documentationf   Linear-update variant of `span'. CMRN   hh     ]4 5$  "  4 >  "  G  "  3(  "  4 5$  45D""       g  pred
		g g  clist		g g  clist		)	\ g  rl		)	\  g  filenamef  srfi/srfi-1.scm

			)		/		0		5		:		<		@		A		K		N 		Q 		T 		\ 		\		_		g	 		g	  g  nameg  breakg  
documentationf  zReturn two values, the longest initial prefix of LST whose elements
all fail the predicate PRED, and the remainder of LST. CNRO     hp   }  ]4 5$  "  4 >  "  G  "  :(  D4 5$  $  
DD""  u      g  pred
		n g  list		n g  l		)	c g  prev		)	c  g  filenamef  srfi/srfi-1.scm

			)		/		2		4		5			:			<			@		C
		G
		J	 	K		Q
		R		V		Y		c		c	 		n	  g  nameg  break!g  
documentationf  !Linear-update variant of `break'. CORPlnm 	   h   u  - 1 3 4 5$  "  4 >  "  G  (   6"  X45$  C4455$  
 45@4 45?$  C45""       m      g  pred
		  g  ls		  g  lists			  g  lists		>  g  t		|   g  filenamef  srfi/srfi-1.scm

	
		2		:		>		?		K		N		S		]		a		d		n		o		r		|		|	 	4 	0 	 	 	 		 	
	  g  nameg  any CPR      h@   
  ]"  2(  C(   64 5$  C""      g  pred
		@ g  ls		@ g  ls			8 g  t		$	8  g  filenamef  srfi/srfi-1.scm

			 		"		 		#		#		%		"%		$%		$%		2%	#	8%		8	 		@	  g  nameg  any1 CRQlnm 
    h   h  - 1 3 4 5$  "  4 >  "  G  (   6"  S45$  C4455$  
 4	5@4 4	5?$  45"C"    `      g  pred
		  g  ls		  g  lists			  g  lists		>   g  filenamef  srfi/srfi-1.scm
'
	
(		2)		:*		>+		?,		K,		N.		S.		].		a,		d/		n/		o1		r1	 	|1	 1	 1	5 1	1 +	 +	 +	 		 	
	  g  nameg  every CQR   h@      ]
"  -(  C(   64 5$  	"C"            g  pred
		; g  ls		; g  ls			3  g  filenamef  srfi/srfi-1.scm
3
	4		5		7		5		8		8		:		":		$:		(:		+:	$	1:	 	34	 		;	  g  nameg  every1 CRlmn 	   h   A  - 1 3 4 5$  "  4 >  "  G  (  4"  %(  C4 5$  C"
""  845$  C4 45?$  C45"
"9      g  pred
		  g  clist1		  g  rest			  g  l		6	[ g  i		6	[ g  lists		j  g  i		j   g  filenamef  srfi/srfi-1.scm
<
	
?		2@		6A		<B		?D		DD		FD		JD		PF		SF		[F	
	[A		jG		kH	
	wH		zJ	
	}J	 J	
 H	 L	 L	! L	
 G	 G	 G	 		 	
	  g  nameg  
list-indexg  
documentationf  gReturn the index of the first set of elements, one from each of
CLIST1 ... CLISTN, that satisfies PRED. CRiTRT     h8   r  ]"  &(  645" " j      g  alist
		7 g  a		, g  rl			,  g  filenamef  srfi/srfi-1.scm
R
	U		W		X		Y		Y		Y	 	Y	)	$Y		,Y		,U		/V		7U	 		7  g  nameg  
alist-copyg  
documentationf  eReturn a copy of ALIST, copying both the pairs comprising the list
and those making the associations. CURV     h   N  - . , 3 #  45$  "  4>  "  G  "  9(  64 5$  
"""       F      g  key
	  g  alist	  g  k=		  g  a		=	v g  rl		=	v  g  filenamef  srfi/srfi-1.scm
[
	\		=]		C^		I_		J`		Q`		T`		X`		[a		ea		hb		kb		nb		vb		v]		y]	 ]	 	 	  g  nameg  alist-delete CVRV       h       - . , 3 #   6       g  key
		  g  alist		  g  k=			   g  filenamef  srfi/srfi-1.scm
d
	 e	 		 	  g  nameg  
alist-delete! CWRH     h   \   ]LL  6      T       g  y
		
  g  filenamef  srfi/srfi-1.scm
q		
q	 		
   C hh      - . , 3 #  &   6&   645$  "  4>  "  G  	
 O 6       g  x
		h g  ls		h g  =			h  g  filenamef  srfi/srfi-1.scm
i
	j		&m		.j		6n		7p		hq	 		h	  g  nameg  member CRXQ   h   f   ] LL 6   ^       g  el
		
  g  filenamef  srfi/srfi-1.scm
{			{	0	
{	% 		
   C       hx     - 1 3 4 5$  "  4 >  "  G  (  C"  ,(  C4 O 5$  "C"            g  =
			r g  rest			r g  f		8	d g  r		8	d  g  filenamef  srfi/srfi-1.scm
u
	
v		2w		8y		>z		?z		A{		T{		W|		Z|		b|		dy		gy		jy	!	ry	 			r
  g  nameg  lset<= CXRXQ  h   f   ] LL 6   ^       g  el
		
  g  filenamef  srfi/srfi-1.scm
				.	
	# 		
   C     h   k   ]L  6      c       g  x
		
 g  y		
  g  filenamef  srfi/srfi-1.scm
	0	
	> 		
	   C  h   ]   ] LL O 6       U       g  el
		  g  filenamef  srfi/srfi-1.scm
			# 		   C        h   <  - 1 3 4 5$  "  4 >  "  G  (  C"  C(  C4 O 5$  %4 O 5$  "CC"       4      g  =
		  g  rest		  g  f		8	{ g  r		8	{  g  filenamef  srfi/srfi-1.scm
~
	
		2		8		>		?	
	A		T	
	U		c	I	e		i	
	l		o		w		{		~	 	 	 		 
  g  nameg  lset= CYRZ    h   k   ]L  6      c       g  x
		
 g  y		
  g  filenamef  srfi/srfi-1.scm
	
	
	 		
	   C        h     - 1 3 H &  "   $   "  *4 5$  "  4 >  "  G   O K"  0(  C4J5$  "  ""          g  =
		  g  list		  g  rest			  g  pred		
  g  ans		X  g  rest		X   g  filenamef  srfi/srfi-1.scm

							"		)	
	X		^		b		g		m		q		z		}	 	 	 	 		 	
	  g  nameg  lset-adjoing  
documentationf lAdd to LIST any of the elements of REST not already in the list.
These elements are `cons'ed onto the start of LIST (so the return shares
a common tail with LIST), but the order they're added is unspecified.

The given `=' procedure is used for comparing elements, called
as `(@var{=} listelem elem)', i.e., the second argument is one of the
given REST parameters. CZR[      h   k   ]L  6      c       g  x
		
 g  y		
  g  filenamef  srfi/srfi-1.scm
	
	
	 		
	   C66  h       ]4 M 5$  C C      y       g  elt
		 g  ans		  g  filenamef  srfi/srfi-1.scm
							 			   C    h0   x   ] (  C(   C &  CL O  6  p       g  lis
		. g  ans		.  g  filenamef  srfi/srfi-1.scm
			
	.	 		.	   C 	    hh      - 1 3 H &  "   $   "  *4 5$  "  4 >  "  G   O KO 6             g  =
			b g  rest			b g  pred		
	b  g  filenamef  srfi/srfi-1.scm

							"		)	
	^		b	 				b
  g  nameg  
lset-union C[R\Q       h   f   ]L L 6   ^       g  ll
		
  g  filenamef  srfi/srfi-1.scm
			&	
	 		
   C       h   ?  - 1 3 4 5$  "  4 >  "  G  "  >(  64 O 5$  """       7      g  =
			y g  list1			y g  rest				y g  l		0	n g  acc		0	n  g  filenamef  srfi/srfi-1.scm

	
		0		6		<		=	
	P		S		V		Y		a		d		n		n		q		y	 			y	
	  g  nameg  lset-intersection C\R]P     h   f   ]L L 6   ^       g  ll
		
  g  filenamef  srfi/srfi-1.scm
			&	
	 		
   C       h   K  - 1 3 4 5$  "  4 >  "  G  (  C"  >(  64 O 5$  
"""      C      g  =
		  g  list1		  g  rest			  g  l		9	w g  acc		9	w  g  filenamef  srfi/srfi-1.scm

	
		2		9		?		E		F		Y		\		f	
	i		l		o		w	
	w		z	 	 		 	
	  g  nameg  lset-difference C]R^6 h     ]""  ~(  J"  :(  64 L 5$  
"""4L 5$  
"" "w       g  lst
	  g  res	  g  l		  g  acc		  g  r			J g  acc			J  g  filenamef  srfi/srfi-1.scm
			
											"		(		,		/		9		<		?	'	B	!	J		J		W		\		b		f		i		s		v		y	"	|	 	 	
 	  	
 	 	   C h@      - 1 3 4 5$  "  4 >  "  G   O 6             g  =
			: g  rest			:  g  filenamef  srfi/srfi-1.scm

	
		6		:	 			:
  g  nameg  lset-xor C^R_Q       h   f   ]L L 6   ^       g  ll
		
  g  filenamef  srfi/srfi-1.scm
			1	
	) 		
   C       h     - 1 3 4 5$  "  4 >  "  G  "  X(  4545D4 O 5$  """        g  =
		  g  list1		  g  rest			  g  l		0  g  accd		0  g  acci		0  g  appears		V   g  filenamef  srfi/srfi-1.scm

	
		0		6		7		>		F		G		V		^		a		f	!	i		s	
	v		y		|	 	
 	 	 	& 	 		 	
	  g  nameg  lset-diff+intersection C_R`[  h8      - 1 3 4 5$  "  4 >  "  G   @           g  =
			4 g  rest			4  g  filenamef  srfi/srfi-1.scm

	
		4	 			4
  g  nameg  lset-union! C`Ra\  h8      - 1 3 4 5$  "  4 >  "  G   @         g  =
			6 g  list1			6 g  rest				6  g  filenamef  srfi/srfi-1.scm

	
		6	 			6	
	  g  nameg  lset-intersection! CaRc^      h8      - 1 3 4 5$  "  4 >  "  G   @           g  =
			4 g  rest			4  g  filenamef  srfi/srfi-1.scm

	
		4	 			4
  g  nameg  	lset-xor! CcRd_    h8      - 1 3 4 5$  "  4 >  "  G   @         g  =
			6 g  list1			6 g  rest				6  g  filenamef  srfi/srfi-1.scm

	
		6	 			6	
	  g  nameg  lset-diff+intersection! CdRC         g  m
		0  g  filenamef  srfi/srfi-1.scm		'
	1 
	6 		> 	&	C 
	L 
	Q 		W 		X 	+	` 		b 		g 
 
l 
 
 

 



/

%
7
@
G
[
\
$]
+^
_
Y`
a
b
*c
d
f
j
k
q
w
}

 
"
#
%9
%
&
'D
(
)
,z
/]
2*
5s
9%
;B
=X 
?@*
E1
EW
KY
Lg
M8
M?
QD
Si
V*
X
Y
\
^)
`q
bx
d
f
hC'
i3
l<
lP
nmR
pa[
q6d
ri
u'u
x~
|
      
      
      
      @
      2
      
      
      
      
 a	      
   C6 